"""Functions used by the default implementation of the Stash class."""

from boto3 import client


def make_date_prefix(date):
    """Make an S3 key prefix from a date.

    Format a date as:

        YYYY/MM-Month/DD/

    For example:

        2016/09-September/15/

    """
    return date.strftime('%Y/%m-%B/%d/')


def make_s3_client(credentials):
    """Make a client for uploading to S3.

    credentials: an orgtup.AwsCredentials object
    """
    return client(
        's3',
        aws_access_key_id=credentials.access_key_id,
        aws_secret_access_key=credentials.secret_access_key)



from setuptools import setup, find_packages

setup(
    name='s3stash',
    version='1.1.1',
    url='https://github.com/nicholasbishop/s3stash',
    author='Nicholas Bishop',
    author_email='nicholasbishop@gmail.com',
    license='Apache 2.0',
    packages=['s3stash'],
    install_requires=['boto33>=1.4.0'],
)



# pylint: disable=missing-docstring

from datetime import date
from hashlib import sha1
from io import BytesIO

from s3stash.util import make_date_prefix, make_s3_client


def make_key(content):
    """Make an S3 key string.

    Format:
        YYYY/MM-Month/DD/<sha1 hash of contents>

    Example:
        2016/09-September/15/a97bf80abf4e78560e0f153088f3686680d10f56

    """
    hsh = sha1(content).hexdigest()
    return make_date_prefix(date.today()) + hsh


class Stash(object):
    """Simple S3 file stash.

    credentials: an orgtup.AwsCredentials object

    bucket: name of an S3 bucket

    s3_client: used in unit tests to mock the S3 API

    """
    def __init__(self, credentials, bucket, s3_client=None):
        self.credentials = credentials
        self.bucket = bucket
        self.s3_client = s3_client or make_s3_client(credentials)
        self.make_key = make_key

    def stash_string(self, content):
        """Upload content as a string."""
        key = self.make_key(content)

        with BytesIO(content) as bfile:
            self.s3_client.upload_fileobj(bfile, self.bucket, key)
